/*
 * Copyright (C) 2022 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.eingang.intelliform;

import static org.assertj.core.api.Assertions.*;

import java.util.List;

import org.junit.jupiter.api.BeforeEach;
import org.junit.jupiter.api.Test;

import de.ozgcloud.eingang.common.formdata.IncomingFile;

class DepositRequestIncomingFileMapperTest {

	private DepositRequestIncomingFileMapper mapper;

	@BeforeEach
	void init() {

		mapper = new DepositRequestIncomingFileMapper();
	}

	@Test
	void validateFileCount() {

		List<IncomingFile> files = mapper.mapFiles(DepositTestFactory.create());

		assertThat(files).isNotEmpty().hasSize(2);
	}

	@Test
	void validateFile1() {

		List<IncomingFile> files = mapper.mapFiles(DepositTestFactory.create());

		IncomingFile file = files.get(0);
		assertThat(file.getContentStream()).hasBinaryContent(AttachmentTestFactory.XML_CONTENT);
		assertThat(file.getContentType()).isEqualTo(AttachmentTestFactory.XML_CONTENT_TYPE);
		assertThat(file.getVendorId()).isEqualTo(AttachmentTestFactory.XML_ID);
		assertThat(file.getName()).isEqualTo(AttachmentTestFactory.XML_NAME);
		assertThat(file.getId()).isNotNull();
	}
}
