package de.ozgcloud.eingang.xta;

import static org.assertj.core.api.Assertions.*;
import static org.mockito.ArgumentMatchers.*;
import static org.mockito.Mockito.*;

import org.junit.jupiter.api.Nested;
import org.junit.jupiter.api.Test;
import org.mapstruct.factory.Mappers;
import org.mockito.InjectMocks;
import org.mockito.Spy;

class XtaMessageMapperTest {

	@Spy
	@InjectMocks
	private XtaMessageMapper mapper = Mappers.getMapper(XtaMessageMapper.class);

	@Nested
	class TestToFormData {

		@Test
		void shouldMapAllToForm() {
			var formData = mapper.toFormData(XtaMessageTestFactory.create());

			assertThat(formData).usingRecursiveComparison().ignoringFields("id", "representations")
					.isEqualTo(FormDataTestFactory.create());
		}

		@Test
		void shouldHaveMessageFileAsRepresentation() {
			var formData = mapper.toFormData(XtaMessageTestFactory.create());

			assertThat(formData.getRepresentations()).hasSize(1);
		}

		@Test
		void shouldCallToIncomingFile() {
			XtaMessage message = XtaMessageTestFactory.create();

			mapper.toFormData(message);

			verify(mapper).toIncomingFile(notNull());
		}

		@Nested
		class ToFormHeader {
			@Test
			void shouldMapToFormHeader() {
				var mapped = mapper.formHeaderFromMetaData(XtaMessageMetaDataTestFactory.create());

				assertThat(mapped).usingRecursiveComparison().isEqualTo(FormHeaderTestFactory.create());
			}
		}

		@Nested
		class ToIncomingFile {
			@Test
			void shouldHaveMessageFile() {
				var inFile = mapper.toIncomingFile(XtaFileTestFactory.create());

				assertThat(inFile.getContentStream()).isNotNull();
			}

			@Test
			void shouldHaveFileName() {
				var inFile = mapper.toIncomingFile(XtaFileTestFactory.create());

				assertThat(inFile.getName()).isEqualTo(XtaFileTestFactory.NAME);
			}

			@Test
			void shouldHaveZipContentType() {
				var inFile = mapper.toIncomingFile(XtaFileTestFactory.create());

				assertThat(inFile.getContentType()).isEqualTo("application/zip");
			}

			@Test
			void shouldHaveSize() {
				var inFile = mapper.toIncomingFile(XtaFileTestFactory.create());

				assertThat(inFile.getSize()).isEqualTo(XtaFileTestFactory.CONTENT.length());
			}

			@Test
			void shouldHandleMissingMessageFile() {
				var fileGroup = mapper.toIncomingFile(null);

				assertThat(fileGroup).isNull();
			}
		}

	}
}
